@@ -73,7 +73,7 @@ def segment_single_image(im,params):
         tmp = im[roi[0]:roi[2],roi[1]:roi[3]]
         tsr,tsc = tmp.shape
         tmp = preprocess(tmp,params)
-        yp = mseg.segment(tmp,exclude = 16)[:,:,0]
+        yp = mseg.segment(tmp,exclude = 16,invert = False)[:,:,0]
         yp = resize(yp,(tsr,tsc))   
         if params['post_process']:
             yp = postprocessing(im[roi[0]:roi[2],roi[1]:roi[3]] if params['invert'] else -im[roi[0]:roi[2],roi[1]:roi[3]],yp,int(standard_width/params['scale']))                
@@ -81,7 +81,7 @@ def segment_single_image(im,params):
         #res[roi[0]:roi[2],roi[1]:roi[3]] = yp
     else:
         tmp = preprocess(im,params)
-        yp = mseg.segment(tmp,exclude = 16)[:,:,0]
+        yp = mseg.segment(tmp,exclude = 16,invert = False)[:,:,0]
         yp = resize(yp,(sr,sc))    
         if params['post_process']:
             yp = postprocessing(im if params['invert'] else -im,yp,int(standard_width/params['scale']))   
@@ -109,7 +109,7 @@ def get_width(viewer: Viewer) -> int:
         mean_width0 = round(mean_width0,2)
         params['scale'] = standard_width/mean_width0   
     except:
-        viewer.add_shapes(shape_type='lines',name = 'cell_width')
+        viewer.add_shapes(shape_type='lines',name = 'cell_width',edge_width=2,edge_color='orange')
         mean_width0 = standard_width
 
     return mean_width0   
@@ -132,9 +132,9 @@ def get_width(viewer: Viewer) -> int:
 
 ## MagicGui widget for single image segmentation
 @magic_factory(auto_call=True,
-adjust_scale = {"widget_type": "FloatSlider", "max": 1.2,"min": 0.8,"step":0.025,'tracking': False,'readout' : True,'tooltip': 'Fine-tune the scale around the mean cell width.'}, 
+adjust_scale = {"widget_type": "FloatSlider", "max": 1.5,"min": 0.7,"step":0.025,'tracking': False,'readout' : True,'tooltip': 'Fine-tune the scale around the mean cell width.'}, 
 noise_var = {"widget_type": "FloatSlider", "max": 0.50,"min": 0.00,"step":0.0001,'tracking': False,'readout' : True,'tooltip': 'Reduce false positives by adding noise.'},
-gamma = {"widget_type": "FloatSlider", "max": 3.0,"min": 0.1,"step":0.1,'tracking': False,'readout' : True,'tooltip': 'Gamma correction.'},
+gamma = {"widget_type": "FloatSlider", "max": 2.5,"min": 0.1,"step":0.05,'tracking': False,'readout' : True,'tooltip': 'Gamma correction.'},
 sharpness_sigma = {"widget_type": "FloatSlider", "max": 3,"min": 0,"step":0.25,'tracking': False,'readout' : True,'tooltip': 'Sharpness scale in unsharp mask.'},
 sharpness_amount = {"widget_type": "FloatSlider", "max": 5,"min": 0.5,"step":0.5,'tracking': False,'readout' : True,'tooltip': 'Sharpness amount in unsharp mask.'},
 run = {"widget_type": "PushButton", 'value': True,'tooltip': 'Run again.'})
@@ -145,7 +145,7 @@ use_local_noise = False,
 gaussian_laplace = False,
 adjust_scale = 1,
 noise_var = 0.0001, 
-gamma= 0.5,
+gamma= 1.0,
 sharpness_sigma= 0,
 sharpness_amount = 0.6,
 post_process= True,
@@ -176,7 +176,10 @@ run = False,) -> 'napari.types.LayerDataTuple':
     params['post_process'] = post_process
     params['use_roi'] = use_roi
 
-    sr,sc = data.shape[-2],data.shape[-1]
+    try:
+        sr,sc = data.shape[-2],data.shape[-1]
+    except:
+        return 0        
     if viewer.dims.ndim == 3:
         fnum = viewer.dims.current_step[0]
         im = np.copy(data[fnum])        
@@ -259,14 +262,11 @@ def save_params(output_folder =  pathlib.Path.home(),filename = 'params'):
     
     json.dump( params, open( filename, 'w' ) )
 
-@magic_factory(filename={'mode': 'r','filter':'.json'},call_button='Load')
+@magic_factory(filename={'mode': 'r',"filter": "*.json"},call_button='Load')
 def load_params(filename =  pathlib.Path.home()):
     '''
     Load parameters to file
     '''
-    output_folder = os.path.normpath(output_folder)
-    filename = output_folder + os.path.sep + filename + '.json'
-    
     params = json.load( open( filename) )
     
 ############ napari hooks
