@@ -14,7 +14,7 @@ from scipy.ndimage import gaussian_laplace
 from skimage.filters import gaussian,laplace
 from skimage.exposure import adjust_gamma
 from skimage.color import label2rgb
-from skimage.morphology import remove_small_objects
+from skimage.morphology import remove_small_objects,remove_small_holes
 from scipy.ndimage import label
 
 def postprocess_ws(im,yp):
@@ -51,5 +51,7 @@ def postprocessing(im,yp,mean_width=10,threshold_high= 0.999,threshold_low = 0.5
     markers = remove_small_objects(yp > threshold_high,0.5*mean_width**2)
     markers,c = label(markers)
     mask = yp > threshold_low
+    mask = remove_small_holes(mask,0.1*mean_width**2)
     ws = watershed(im,markers = markers,mask = mask,watershed_line= True)
+
     return ws
\ No newline at end of file
